@@ -8,24 +8,14 @@ function delete_line(y_line)
     local color
 
     width=u61_map_get_width()
-    y=y_line
-    while y>1 do
-        x=0
-        while x<width do
-            color=u61_map_get_square_color(x,y-1)
-            u61_map_set_square_color(x,y,color)
-            x=x+1
-        end
-        y=y-1
-    end
     x=0
     while x<width do
-        u61_map_set_square_color(x,0,-1)
+        column_down(x,y_line)
         x=x+1
     end
 end
 
-function match_line()
+function match_line(match_count)
     local x
     local y
     local width
@@ -38,7 +28,7 @@ function match_line()
 
     lines=0
     y=0
-    while y<height do
+    while y<height and lines==0 do
         holes=0
         x=0
         while x<width do
@@ -53,5 +43,12 @@ function match_line()
         end
         y=y+1
     end    
+
+    if lines>0 then
+        u61_map_add_score((match_count+1)*1000)    
+    end
+--    print(lines)
+
+    return lines
 end
 
