@@ -406,3 +406,26 @@ void U61_Block::draw_prevision(int x,int y,int size)
         }
     }
 }
+
+/*--------------------------------------------------------------------------*/
+/*
+ * draws the preview of a block onto the screen (not the same clip)
+ */
+void U61_Block::draw_preview(int x,int y,int size)
+{
+    int i;
+    int x2,y2;
+
+    for (i=0;i<nb_items;++i)
+    {
+        x2=items[i].get_x();
+        y2=items[i].get_y();
+        if (x2>=-PREVIEW_WIDTH/2 && y2>=-PREVIEW_HEIGHT/2
+            && x2<PREVIEW_WIDTH/2 && y2<PREVIEW_HEIGHT/2)
+        {
+            x2=x+x2*U61_Global::data.square_w[size];
+            y2=y+y2*U61_Global::data.square_h[size];
+            items[i].square.draw(x2,y2,size);
+        }
+    }
+}
