@@ -184,6 +184,12 @@ bool U61_Data::load2()
             //cout<<"Loading background\n";
 	    success=success && load_back();
         }
+
+        if (success)
+        {
+            //cout<<"Loading info\n";
+	    success=success && load_info();
+        }
     }
     else
     {
@@ -417,3 +423,32 @@ bool U61_Data::load_back()
 
     return success;
 }
+
+/*--------------------------------------------------------------------------*/
+/*
+ * loads the info textures (where scores are displayed)
+ */
+bool U61_Data::load_info()
+{
+    bool success=true;
+
+    info[SIZE_BIG]=CL_Surface::load(ID_INFO_BIG,manager);
+    success=success && (info[SIZE_BIG]!=NULL);
+    info[SIZE_SMALL]=CL_Surface::load(ID_INFO_SMALL,manager);
+    success=success && (info[SIZE_SMALL]!=NULL);
+
+    if (!success)
+    {
+        cout<<"Info loading failed\n";
+    }
+    else
+    {
+        info_w[SIZE_SMALL]=info[SIZE_SMALL]->get_width();
+        info_h[SIZE_SMALL]=info[SIZE_SMALL]->get_height();
+        info_w[SIZE_BIG]=info[SIZE_BIG]->get_width();
+        info_h[SIZE_BIG]=info[SIZE_BIG]->get_height();
+    }
+
+    return success;
+}
+
