@@ -445,9 +445,54 @@ void U61_Game::start_local_alone()
  */
 void U61_Game::start_local_multiplayer()
 {
+    int num0,num1,num2,num3;
     //cout<<"local multiplayer game started\n";
     if (standard_init())
     {
+        num0=get_local_player(0);
+        player[0].init_local(&(player_input[num0]),0,
+            &(U61_Global::config.player[num0]));
+
+        num1=get_local_player(1);
+        if (num1<0)
+        {
+            layout.init_alone(&(player[0]));
+        }
+        else
+        {
+            player[1].init_local(&(player_input[num1]),0,
+                &(U61_Global::config.player[num1]));
+
+            num2=get_local_player(2);
+            if (num2<0)
+            {
+                layout.init_multiplayer_2(&(player[0]),
+                                          &(player[1]));
+            }
+            else
+            {
+                player[2].init_local(&(player_input[num2]),0,
+                    &(U61_Global::config.player[num2]));
+                
+                num3=get_local_player(3);
+                if (num3<0)
+                {
+                    layout.init_multiplayer_3(&(player[0]),
+                                              &(player[1]),
+                                              &(player[2]));
+                }
+                else
+                {
+                    player[3].init_local(&(player_input[num3]),0,
+                        &(U61_Global::config.player[num3]));
+                    
+                    layout.init_multiplayer_4(&(player[0]),
+                                              &(player[1]),
+                                              &(player[2]),
+                                              &(player[3]));
+                }
+            }
+        }
     }
 }
 
