@@ -39,6 +39,7 @@
  includes
  ---------------------------------------------------------------------------*/
 
+#include "data.h"
 #include "layoutitem.h"
 #include "layout.h"
 #include "global.h"
@@ -103,8 +104,13 @@ void U61_LayoutItem::init(U61_Player *p,int x,int y,int s)
  */
 void U61_LayoutItem::calc_coords()
 {
+    int total_y;
+
+    total_y=U61_Global::data.map_h[size]+U61_Global::data.info_h[size];
     x_map=x_center-U61_Global::data.map_w[size]/2;
-    y_map=y_center-U61_Global::data.map_h[size]/2;
+    y_map=y_center-total_y/2;
+    x_info=x_center-U61_Global::data.info_w[size]/2;
+    y_info=y_map+U61_Global::data.map_h[size];
 }
 
 /*--------------------------------------------------------------------------*/
@@ -133,9 +139,18 @@ void U61_LayoutItem::draw_background(CL_Canvas *target)
  */
 void U61_LayoutItem::draw()
 {
+    char buffer[U61_STRING_SIZE];
+
     if (active)
     {
         player->draw(x_map,y_map,size);
+
+        U61_Global::data.info[size]->put_screen(x_info,y_info);
+
+        sprintf(buffer,"%d",player->get_score());
+        U61_Global::data.font_menu->print_left
+            (x_info+20,y_info+20,buffer);
+        player->get_next_block().draw_preview(x_center,y_info+60,size);
 //        U61_Global::data.font_menu->print_left
 //            (x_map,y_map,player->get_name());
     }
