@@ -41,6 +41,7 @@
 
 #include "letter.h"
 #include "time.h"
+#include "utils.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -83,8 +84,8 @@ void U61_Letter::enable_dance()
 
         last_time=U61_Time::for_effect();
 
-        dx=0; 
-        dy=0; 
+        change_dx();
+        change_dy();
         change_vx();
         change_vy();
     }
@@ -120,11 +121,13 @@ void U61_Letter::compute()
         {
             dx-=vx;
             change_vx();
+//            change_vy();
         }
         if (dy<-H_MAX_MOVE||dy>H_MAX_MOVE)
         {
             dy-=vy;
             change_vy();
+//            change_vx();
         }
 
         last_time+=SLOW_FACTOR;
@@ -137,13 +140,14 @@ void U61_Letter::compute()
  */
 void U61_Letter::change_vx()
 {
-    static int choice=-1;
-
-    if (U61_Time::for_effect()%2)
+    if (vx!=1 && vx!=-1)
     {
-        choice=(choice==-1) ? 1 : -1;
+        vx=1;
+    }
+    if (U61_Utils::random(2))
+    {
+        vx=-vx;
     }
-    vx=choice;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -152,13 +156,32 @@ void U61_Letter::change_vx()
  */
 void U61_Letter::change_vy()
 {
-    static int choice=-1;
-
-    if (U61_Time::for_effect()%2)
+    if (vy!=1 && vy!=-1)
     {
-        choice=(choice==-1) ? 1 : -1;
+        vy=1;
     }
-    vy=choice;
+    if (U61_Utils::random(2))
+    {
+        vy=-vy;
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * finds a new dx value
+ */
+void U61_Letter::change_dx()
+{
+    dx=U61_Utils::random(W_MAX_MOVE)-W_MAX_MOVE/2;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * finds a new dy value
+ */
+void U61_Letter::change_dy()
+{
+    dy=U61_Utils::random(H_MAX_MOVE)-H_MAX_MOVE/2;
 }
 
 /*--------------------------------------------------------------------------*/
