@@ -48,6 +48,8 @@
 #include "map.h"
 #include "script.h"
 #include "time.h"
+#include "sound.h"
+#include "utils.h"
 
 /*---------------------------------------------------------------------------
  globals
@@ -60,11 +62,11 @@
  */ 
 const int U61_Map::speeds[MAX_SYSTEM_SPEED+1]=
     {
-       2,  5, 10, 20, 30, 35, 40, 45, 50, 55, 60,
-          65, 70, 75, 80, 85, 90, 95,100,105,110,
-         114,118,122,126,130,134,138,142,144,150,
-         153,156,159,162,165,168,171,174,177,180,
-         182,184,186,188,190,192,194,196,198,200
+       2,  5, 10, 15, 20, 30, 40, 50, 60, 70, 80,
+          85,90,95,100,105,110,115,120,125,130,
+         135,140,145,150,155,160,170,180,190,200,
+         210,220,230,240,250,260,270,280,290,300,
+         310,320,330,340,350,360,370,380,390,400
     };
 const int U61_Map::accels[MAX_SYSTEM_ACCEL+1]=
     {
@@ -121,18 +123,32 @@ void U61_Map::clear()
  */
 void U61_Map::begin()
 {
+    int i;
+
     auto_events.clear();
     
     clear();
  
     block.reset();
     block_requested=false;
+    matching=false;
     speed_counter=0;
     accel_counter=0;
     speed=base_speed;
     accel=base_accel; 
     background=0;
     prevision_state=true;
+    preview_state=true;
+    match_count=0;
+    if (score>best_score)
+    {
+        best_score=score;
+    }
+    score=0;
+    for (i=0;i<NB_GLOBAL;++i)
+    {
+        global_val[i]=0;
+    }        
     //block.shape(0);
 }
 
@@ -144,10 +160,12 @@ void U61_Map::reset(int s,int a)
 {
     map_time=0;
     active=false;
+    best_score=0;
     score=0;
     games=0; 
     base_speed=s;
     base_accel=a;
+    silent=false;
 
     begin();
 }
@@ -280,6 +298,85 @@ int U61_Map::get_score()
     return score;
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * gets the best score associated to the map
+ */
+int U61_Map::get_best_score()
+{
+    return best_score;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * adds the given value to the current score
+ */
+void U61_Map::add_score(int s)
+{
+    score+=s;
+    if (score<0)
+    {
+        score=0;
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * gets the time associated to the map
+ */
+int U61_Map::get_time()
+{
+    return map_time;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * gets the number of games associated to the map
+ */
+int U61_Map::get_nb_games()
+{
+    return games;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * returns a number which is used by the lua match function
+ */
+int U61_Map::get_match_count()
+{
+    return match_count;
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * sets a global integer into the map
+ * used for lua scripts to store global permanent values
+ */
+void U61_Map::set_global(int i, int glob)
+{
+    if (i>=0 && i<NB_GLOBAL)
+    {
+        global_val[i]=glob;
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * gets a global integer from the map
+ * used for lua scripts to store global permanent values
+ */
+int U61_Map::get_global(int i)
+{
+    int glob=0;
+
+    if (i>=0 && i<NB_GLOBAL)
+    {
+        glob=global_val[i];
+    }
+
+    return glob;
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * compute the map to the next instant
@@ -288,6 +385,14 @@ void U61_Map::compute_next()
 {
     //cout<<"Compute next\n";
     map_time++;
+    if (!(map_time%TIME_CALLBACK_DELAY))
+    {
+        time_callback();
+        if (matching)
+        {
+            match_pattern();
+        }
+    }
     update_speed();
 }
 
@@ -370,7 +475,7 @@ void U61_Map::handle_event(U61_Event event)
                 block_drop();
                 break;
             case U61_Event::NEW_BLOCK:
-                new_block();
+                new_block(event.par);
                 break;
             case U61_Event::LOOSE:
                 loose();
@@ -410,10 +515,11 @@ void U61_Map::poll_auto_events()
 
     if (active)
     {
-        if ((!is_block_active()) && (!block_requested))
+        if ((!is_block_active()) && (!block_requested) && (!matching))
         {
             block_requested=true;
             event.code=U61_Event::NEW_BLOCK;
+            event.par=U61_Utils::random(U61_Block::MAX_SHAPE);
             put_auto_event(event);
             //cout<<"new block event sent\n";
         }
@@ -497,6 +603,15 @@ void U61_Map::draw(int x,int y, int size, bool prev)
 //    cout<<"draw square\n";
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * sets the map in a mute state (does not generate sounds any more)
+ */
+void U61_Map::mute()
+{
+    silent=true;
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * sets the prevision state
@@ -515,6 +630,24 @@ bool U61_Map::get_prevision_state()
     return prevision_state; 
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * sets the preview state
+ */
+void U61_Map::set_preview_state(bool state)
+{
+    preview_state=state; 
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * gets the preview state
+ */
+bool U61_Map::get_preview_state()
+{
+    return preview_state; 
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * sets the speed 
@@ -585,6 +718,15 @@ void U61_Map::check_accel()
     }
 }
 
+/*--------------------------------------------------------------------------*/
+/*
+ * gets the nest block 
+ */
+U61_Block U61_Map::get_next_block()
+{
+    return next_block; 
+}
+
 /*--------------------------------------------------------------------------*/
 /*
  * display the prevision, the prevision is "where the block will land if
@@ -825,13 +967,14 @@ bool U61_Map::is_block_ok(U61_Block *test)
  * gets a new block, the shape of the new block is calculated with
  * Lua user defined functions
  */
-void U61_Map::new_block()
+void U61_Map::new_block(int shape)
 {
-    static int temp_random=0;
-
-    block.shape(temp_random++);
+    block=next_block;
     block.set_x(WIDTH/2);
     block_requested=false;
+
+    next_block.shape(shape);
+
     //cout<<"new block given\n";
 }
 
@@ -868,7 +1011,8 @@ void U61_Map::stabilize_block()
     }
     else
     {
-        match_pattern();
+        match_count=0;
+        matching=true;
     }
 
     block.reset();
@@ -894,5 +1038,35 @@ void U61_Map::loose()
  */
 void U61_Map::match_pattern()
 {
-    U61_Script::map_match_pattern(this);
+    if (matching)
+    {
+        if ((U61_Script::map_match_pattern(this)))
+        {
+            if (!silent)
+            {
+                U61_Sound::play_block_pattern();
+            }
+            match_count++;
+        }
+        else
+        {
+            if (match_count==0 && !silent)
+            {
+                U61_Sound::play_block_touch();
+            }
+            matching=false;
+        }
+    }
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * calls the lua function time_callback
+ * its purpose is to provide control to lua scripts over the game
+ * in general. since this function is called on a regular basis
+ * it's possible for instance to make the block change now & then
+ */
+void U61_Map::time_callback()
+{
+    U61_Script::map_time_callback(this,&block);
 }
