@@ -40,12 +40,40 @@
  ---------------------------------------------------------------------------*/
 
 #include "menu.h"
+#include "time.h"
 #include "sound.h"
+#include "global.h"
+#include "menuinput.h"
 
 /*---------------------------------------------------------------------------
  globals
  ---------------------------------------------------------------------------*/
 
+/*--------------------------------------------------------------------------*/
+/*
+ * messages displayed at the bottom of the screen in the menus
+ */
+char *U61_Menu::bottom_message[BOTTOM_MESSAGE_NB]=
+{
+    "U61, another block-game by U-Foot",
+    "Copyright (C) 2000 Christian Mauduit",
+    "Home page : http://www.ufoot.org/u61",
+    "Contact author : ufoot@ufoot.org",
+    "Use the arrows to navigate through the menus",
+    "Press escape to return to the previous menu",
+    "Game rules can be changed easily by writing new lua scripts, try it!",
+    "This is only an alpha version...",
+    "U61 uses ClanLib http://clanlib.org",
+    "Graphics by U-Woman http://www.adlerhome.com"
+};
+
+/*--------------------------------------------------------------------------*/
+/*
+ * used to display the messages at the bottom of the screen as a moving banner
+ */
+int U61_Menu::current_bottom_message=0;
+int U61_Menu::bottom_message_start_time=0;
+int U61_Menu::bottom_message_width=-1000000;
 
 /*---------------------------------------------------------------------------
  functions
@@ -55,9 +83,11 @@
 /* 
  * creation of an empty menu
  */ 
-U61_Menu::U61_Menu(U61_Menu *parent)
+U61_Menu::U61_Menu(U61_Menu *parent,char *top)
 {
     parent_menu=parent;
+    top_message=top;
+    message_active=true;
 }
 
 /*--------------------------------------------------------------------------*/
@@ -88,30 +118,33 @@ U61_Menu *U61_Menu::action(int key)
     next_menu=this;
     old_selection=selection;
 
-    switch (key)
+    if (!(items[selection]->is_modal()))
     {
-    case 11:
-        select_up();
-        break;
-    case 10:
-        select_down();
-        break;
-    case 0:
-        next_menu=back();
-        break;
-    case 13:
-        next_menu=validate();
-        break;
-    default:
-        if (items[selection]->action(key))
+        switch (key)
         {
-            U61_Sound::play_menu_move();
+        case U61_MenuInput::KEY_UP:
+            select_up();
+            break;
+        case U61_MenuInput::KEY_DOWN:
+            select_down();
+            break;
+        case U61_MenuInput::KEY_ESCAPE:
+            next_menu=back();
+            break;
+        case U61_MenuInput::KEY_ENTER:
+            next_menu=validate();
+            break;
         }
-        items[selection]->update();
-        items[selection]->select();
-        break;
     }
 
+    if (items[selection]->action(key))
+    {
+        U61_Sound::play_menu_move();
+    }
+
+    items[selection]->update();
+    items[selection]->select();
+
     if (next_menu!=this)
     {
         U61_Sound::play_menu_validate();
@@ -157,8 +190,7 @@ void U61_Menu::draw()
     int last_item_height2;
     int item_height;
 
-
-    y=240;
+    y=U61_Global::data.screen_h/2;
 
     y-=get_height()/2;
     last_item_height2=0;
@@ -172,6 +204,12 @@ void U61_Menu::draw()
         items[i]->draw(y);
         last_item_height2=item_height-item_height/2;
     }
+
+    if (message_active)
+    {
+        draw_top_message();
+        draw_bottom_message();
+    }
 }
 
 /*--------------------------------------------------------------------------*/
@@ -285,3 +323,60 @@ void U61_Menu::add_item(U61_MenuItem *item)
 {
     items.push_back(item);
 }
+
+/*--------------------------------------------------------------------------*/
+/*
+ * draws the top message only
+ */
+void U61_Menu::draw_top_message()
+{
+    int x,y;
+
+    x=(U61_Global::data.screen_w-
+       U61_Global::data.font_menu->get_text_width(top_message))/2;
+    y=0;
+
+    U61_Global::data.font_menu->print_left(x,y,top_message);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * draws the bottom message only
+ */
+void U61_Menu::draw_bottom_message()
+{
+    int x,y=0,dx;
+
+    dx=(U61_Time::for_effect()-bottom_message_start_time)
+        /BOTTOM_MESSAGE_DELAY;
+    if (dx>=U61_Global::data.screen_w+bottom_message_width)
+    {
+        init_bottom_message(); 
+        dx=0;
+    }
+
+    x=U61_Global::data.screen_w-dx;
+    y=U61_Global::data.screen_h-U61_Global::data.font_menu->get_height();
+
+    U61_Global::data.font_menu->print_left
+        (x,y,bottom_message[current_bottom_message]);
+}
+
+/*--------------------------------------------------------------------------*/
+/*
+ * inits the bottom message
+ */
+void U61_Menu::init_bottom_message()
+{
+    current_bottom_message++;
+    if (current_bottom_message>=BOTTOM_MESSAGE_NB)
+    {
+        current_bottom_message=0;
+    }
+
+    bottom_message_start_time=U61_Time::for_effect();
+
+    bottom_message_width=U61_Global::data.font_menu->get_text_width
+        (bottom_message[current_bottom_message]);
+}
+
