@@ -54,8 +54,12 @@ class U61_Platform
 public:
     static char *get_config_file();
     static char *get_data_path();
-
+    
+    static bool open_dir(char *dir,char *ext="");
+    static char *next_file();
+    static bool close_dir(); 
 protected:
+    
 };
 
 #endif
